2025-12-18 Version: 5.4.1
- Update API GetResourceOverview: add response parameters Body.data.riskOverview.


2025-12-17 Version: 5.4.0
- Support API UpdateService.


2025-12-11 Version: 5.3.0
- Support API CreateSource.
- Support API DeleteSource.
- Support API GetSource.


2025-12-05 Version: 5.2.1
- Update API CreateMcpServer: add request parameters body.grayMcpServerConfigs.
- Update API GetMcpServer: add response parameters Body.data.grayMcpServerConfigs.
- Update API UpdateMcpServer: add request parameters body.grayMcpServerConfigs.


2025-12-05 Version: 5.2.0
- Support API CreateServiceVersion.
- Support API DeleteServiceVersion.
- Support API UpdateServiceVersion.


2025-11-25 Version: 5.1.1
- Update API ListGateways: add response parameters Body.data.items.$.loadBalancers.$.ipv4Addresses.
- Update API ListGateways: add response parameters Body.data.items.$.loadBalancers.$.ipv6Addresses.


2025-11-20 Version: 5.1.0
- Support API ListGatewayFeatures.


2025-11-06 Version: 5.0.3
- Update API CreateMcpServer: add request parameters body.createFromType.
- Update API UpdateMcpServer: add request parameters body.createFromType.


2025-11-03 Version: 5.0.2
- Generated python 2024-03-27 for APIG.

2025-10-29 Version: 5.0.1
- Update API GetGateway: add response parameters Body.data.loadBalancers.$.ipv4Addresses.
- Update API GetGateway: add response parameters Body.data.loadBalancers.$.ipv6Addresses.
- Update API ListMcpServers: add response parameters Body.data.items.$.apiId.


2025-10-13 Version: 5.0.0
- Support API CreateMcpServer.
- Support API DeleteMcpServer.
- Support API DeployMcpServer.
- Support API GetMcpServer.
- Support API InstallPlugin.
- Support API ListMcpServers.
- Support API UnDeployMcpServer.
- Support API UninstallPlugin.
- Support API UpdateMcpServer.
- Update API CreateGateway: add request parameters body.gatewayEdition.
- Update API CreateHttpApi: add request parameters body.firstByteTimeout.
- Update API GetGateway: add response parameters Body.data.gatewayEdition.
- Update API GetGateway: add response parameters Body.data.maintenancePeriod.
- Update API ImportHttpApi: add request parameters body.gatewayId.
- Update API ImportHttpApi: update request parameters body.deployConfigs' type has changed.
- Update API ImportHttpApi: update request parameters body.deployConfigs' ref has changed.
- Update API ListGateways: add response parameters Body.data.items.$.gatewayEdition.
- Update API ListHttpApiOperations: add request parameters enableAuth.
- Update API UpdateHttpApi: add request parameters body.firstByteTimeout.


2025-08-06 Version: 4.4.1
- Generated python 2024-03-27 for APIG.

2025-08-05 Version: 4.4.0
- Support API CreateAndAttachPolicy.
- Support API ListPolicies.
- Support API UpdateAndAttachPolicy.


2025-07-25 Version: 4.3.2
- Update API ListPolicyClasses: add request parameters attachResourceId.
- Update API ListPolicyClasses: add request parameters gatewayId.


2025-07-24 Version: 4.3.1
- Update API CreateConsumerAuthorizationRules: add request parameters body.authorizationRules.$.resourceIdentifier.parentResourceId.
- Update API CreateConsumerAuthorizationRules: add request parameters body.authorizationRules.$.resourceIdentifier.resources.
- Update API CreateHttpApiRoute: add request parameters body.mcpRouteConfig.mcpStatisticsEnable.
- Update API GetDashboard: add request parameters routeId.
- Update API QueryConsumerAuthorizationRules: add request parameters resourceTypes.
- Update API UpdateHttpApiRoute: add request parameters body.mcpRouteConfig.
- Update API UpdateHttpApiRoute: add request parameters body.name.


2025-07-21 Version: 4.3.0
- Support API BatchDeleteConsumerAuthorizationRule.
- Support API CreateConsumer.
- Support API CreateConsumerAuthorizationRule.
- Support API CreateConsumerAuthorizationRules.
- Support API CreateGateway.
- Support API DeleteConsumer.
- Support API DeleteConsumerAuthorizationRule.
- Support API GetConsumer.
- Support API GetConsumerAuthorizationRule.
- Support API ListConsumers.
- Support API QueryConsumerAuthorizationRules.
- Support API RemoveConsumerAuthorizationRule.
- Support API UpdateConsumer.
- Support API UpdateConsumerAuthorizationRule.


2025-07-18 Version: 4.2.3
- Update API GetGateway: add response parameters Body.data.isp.


2025-07-17 Version: 4.2.2
- Update API CreateHttpApi: add request parameters body.modelCategory.
- Update API CreateHttpApi: add request parameters body.removeBasePathOnForward.
- Update API UpdateHttpApi: add request parameters body.removeBasePathOnForward.


2025-07-03 Version: 4.2.1
- Update API ListZones: add response parameters Body.data.items.$.supportQat.


2025-06-26 Version: 4.2.0
- Support API DeleteService.
- Update API CreateHttpApi: add request parameters body.agentProtocols.
- Update API CreateService: add request parameters body.serviceConfigs.$.agentServiceConfig.
- Update API UpdateHttpApi: add request parameters body.agentProtocols.


2025-06-11 Version: 4.1.0
- Support API ListPluginAttachments.
- Update API GetGateway: add response parameters Body.data.gatewayType.


2025-06-06 Version: 4.0.4
- Generated python 2024-03-27 for APIG.

2025-06-03 Version: 4.0.3
- Update API ListPlugins: add request parameters includeBuiltinAiGateway.


2025-05-29 Version: 4.0.2
- Update API CreateHttpApiRoute: add request parameters body.mcpRouteConfig.


2025-05-21 Version: 4.0.1
- Update API UpdateHttpApi: add request parameters body.onlyChangeConfig.


2025-05-21 Version: 4.0.0
- Support API CreatePluginAttachment.
- Support API DeletePluginAttachment.
- Support API GetPluginAttachment.
- Support API ListPlugins.
- Support API UpdatePluginAttachment.
- Update API CreateDomain: add request parameters body.gatewayType.
- Update API CreateHttpApi: add request parameters body.ingressConfig.clusterId.
- Update API CreateHttpApiRoute: add request parameters body.deployConfigs.
- Update API DeployHttpApi: add request parameters body.httpApiConfig.
- Update API DeployHttpApi: add request parameters body.restApiConfig.gatewayId.
- Update API DeployHttpApi: add request parameters body.restApiConfig.operationIds.
- Update API GetResourceOverview: add request parameters gatewayType.
- Update API GetResourceOverview: add request The number of query or body parameters has changed from zero to many.
- Update API ImportHttpApi: add request parameters body.deployConfigs.
- Update API ImportHttpApi: add request parameters body.mcpRouteId.
- Update API ListDomains: add request parameters gatewayType.
- Update API ListEnvironments: add request parameters gatewayType.
- Update API ListGateways: add request parameters gatewayType.
- Update API ListGateways: add response parameters Body.data.items.$.gatewayType.
- Update API ListGateways: add response parameters Body.data.items.$.legacy.
- Update API ListHttpApiOperations: add request parameters forDeploy.
- Update API ListHttpApiOperations: add request parameters gatewayId.
- Update API ListHttpApiRoutes: add request parameters forDeploy.
- Update API ListHttpApis: add request parameters gatewayType.
- Update API UndeployHttpApi: add request parameters body.gatewayId.
- Update API UndeployHttpApi: add request parameters body.operationId.
- Update API UpdateHttpApiRoute: add request parameters body.deployConfigs.


2025-04-14 Version: 3.2.2
- Update API ListServices: add request parameters sourceTypes.


2025-03-31 Version: 3.2.1
- Update API GetDashboard: add request parameters pluginId.
- Update API GetDashboard: add request parameters upstreamCluster.
- Update API ListHttpApis: add request parameters withAPIsPublishedToEnvironment.
- Update API ListHttpApis: add request parameters withPolicyConfigs.


2025-03-19 Version: 3.2.0
- Support API UndeployHttpApi.
- Update API CreateDomain: update param body.
- Update API CreateService: update param body.
- Update API GetDomain: update response param.
- Update API UpdateDomain: update param body.


2025-02-26 Version: 3.1.0
- Support API CreateService.
- Support API GetService.
- Support API ListHttpApiRoutes.
- Support API ListServices.


2025-02-14 Version: 3.0.0
- Support API ChangeResourceGroup.
- Support API CreateHttpApiRoute.
- Support API CreatePolicy.
- Support API CreatePolicyAttachment.
- Support API DeleteGatewaySecurityGroupRule.
- Support API DeleteHttpApiRoute.
- Support API DeletePolicy.
- Support API DeletePolicyAttachment.
- Support API DeployHttpApi.
- Support API ExportHttpApi.
- Support API GetDashboard.
- Support API GetPolicy.
- Support API GetPolicyAttachment.
- Support API GetResourceOverview.
- Support API GetTraceConfig.
- Support API ImportHttpApi.
- Support API ListPolicyClasses.
- Support API ListSslCerts.
- Support API ListZones.
- Support API RestartGateway.
- Support API UpdateGatewayFeature.
- Support API UpdateGatewayName.
- Support API UpdateHttpApiRoute.
- Support API UpdatePolicy.
- Support API UpgradeGateway.
- Update API CreateHttpApi: update param body.
- Update API GetDomain: update response param.
- Update API ListGateways: add param tag.
- Update API ListGateways: delete param tags.
- Update API ListGateways: update response param.
- Update API ListHttpApis: add param withIngressInfo.
- Update API UpdateDomain: update param body.
- Update API UpdateHttpApi: update param body.


2024-12-03 Version: 2.0.1
- Update API CreateDomain: update param body.
- Update API GetDomain: update response param.
- Update API ListHttpApiOperations: add param withPluginAttachmentByPluginId.
- Update API ListHttpApis: add param withAuthPolicyList.
- Update API ListHttpApis: add param withEnvironmentInfoById.
- Update API ListHttpApis: add param withPluginAttachmentByPluginId.
- Update API UpdateDomain: update param body.


2024-11-26 Version: 2.0.0
- Support API GetHttpApiRoute.
- Delete API CreateGatewayRoute.
- Delete API CreateGatewayService.
- Delete API CreateGatewayServiceVersion.
- Delete API CreateServiceSource.
- Delete API DeleteGatewayRoute.
- Delete API DeleteGatewayService.
- Delete API DeleteGatewayServiceVersion.
- Delete API DeleteServiceSource.
- Delete API GetGatewayRoute.
- Delete API GetGatewayService.
- Delete API ListGatewayRoutes.
- Delete API ListGatewayServices.
- Delete API OfflineGatewayRoute.
- Delete API OfflineHttpApi.
- Delete API PublishGatewayRoute.
- Delete API PublishHttpApi.
- Delete API UpdateGatewayRoute.
- Delete API UpdateGatewayService.
- Delete API UpdateGatewayServiceVersion.
- Delete API UpdateServiceSource.
- Update API CreateDomain: update param body.
- Update API CreateEnvironment: update param body.
- Update API CreateHttpApi: add param RegionId.
- Update API CreateHttpApi: update param body.
- Update API GetDomain: add param withStatistics.
- Update API GetDomain: update response param.
- Update API GetEnvironment: add param withStatistics.
- Update API GetEnvironment: add param withVpcInfo.
- Update API GetEnvironment: update response param.
- Update API GetGateway: update response param.
- Update API ListDomains: add param resourceGroupId.
- Update API ListEnvironments: add param resourceGroupId.
- Update API ListEnvironments: update response param.
- Update API ListGateways: add param resourceGroupId.
- Update API ListGateways: add param tags.
- Update API ListGateways: update response param.
- Update API ListHttpApiOperations: add param consumerAuthorizationRuleId.
- Update API ListHttpApiOperations: add param withConsumerInEnvironmentId.
- Update API ListHttpApiOperations: add param withConsumerInfoById.
- Update API ListHttpApis: add param gatewayId.
- Update API ListHttpApis: add param resourceGroupId.
- Update API ListHttpApis: add param types.
- Update API ListHttpApis: add param withAuthPolicyInEnvironmentId.
- Update API ListHttpApis: add param withConsumerInfoById.
- Update API ListHttpApis: add param withEnvironmentInfo.
- Update API ListHttpApis: delete param publishedOnly.
- Update API ListHttpApis: update param keyword.
- Update API ListHttpApis: update param name.
- Update API ListHttpApis: update param pageNumber.
- Update API ListHttpApis: update param pageSize.
- Update API UpdateDomain: update response param.
- Update API UpdateHttpApi: update param body.


2024-08-08 Version: 1.0.5
- Generated python 2024-03-27 for APIG.

2024-08-06 Version: 1.0.4
- Update API ListGateways: update response param.


2024-08-05 Version: 1.0.3
- Update API ListHttpApiOperations: add param name.
- Update API ListHttpApis: add param name.


2024-08-05 Version: 1.0.3
- Update API ListHttpApiOperations: add param name.
- Update API ListHttpApis: add param name.


2024-07-29 Version: 1.0.2
- Update API ListDomains: add param gatewayId.


2024-07-26 Version: 1.0.1
- Update API ListHttpApis: add param publishedOnly.


2024-07-25 Version: 1.0.0
- Generated python 2024-03-27 for APIG.

